Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type KinOpenAPI ¶
type KinOpenAPI struct {
// contains filtered or unexported fields
}
func NewKinOpenAPI ¶
func NewKinOpenAPI(fs afero.Fs) *KinOpenAPI
type Loader ¶
type Loader interface {
Load(ctx context.Context, def v1alpha1.OpenAPIDefinition) (*openapi3.T, error)
}
Loader loads an OpenAPI spec based on the provided definition.
func NewLoader ¶
func NewLoader(file *KinOpenAPI, pkgResolver *PackageResolver) Loader
type LoaderMock ¶
LoaderMock is an autogenerated mock type for the Loader type
func NewLoaderMock ¶
func NewLoaderMock(t interface {
mock.TestingT
Cleanup(func())
}) *LoaderMock
NewLoaderMock creates a new instance of LoaderMock. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*LoaderMock) EXPECT ¶
func (_m *LoaderMock) EXPECT() *LoaderMock_Expecter
func (*LoaderMock) Load ¶
func (_mock *LoaderMock) Load(ctx context.Context, def v1alpha1.OpenAPIDefinition) (*openapi3.T, error)
Load provides a mock function for the type LoaderMock
type LoaderMock_Expecter ¶
type LoaderMock_Expecter struct {
// contains filtered or unexported fields
}
func (*LoaderMock_Expecter) Load ¶
func (_e *LoaderMock_Expecter) Load(ctx interface{}, def interface{}) *LoaderMock_Load_Call
Load is a helper method to define mock.On call
- ctx context.Context
- def v1alpha1.OpenAPIDefinition
type LoaderMock_Load_Call ¶
LoaderMock_Load_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Load'
func (*LoaderMock_Load_Call) Return ¶
func (_c *LoaderMock_Load_Call) Return(t *openapi3.T, err error) *LoaderMock_Load_Call
func (*LoaderMock_Load_Call) Run ¶
func (_c *LoaderMock_Load_Call) Run(run func(ctx context.Context, def v1alpha1.OpenAPIDefinition)) *LoaderMock_Load_Call
func (*LoaderMock_Load_Call) RunAndReturn ¶
func (_c *LoaderMock_Load_Call) RunAndReturn(run func(ctx context.Context, def v1alpha1.OpenAPIDefinition) (*openapi3.T, error)) *LoaderMock_Load_Call
type PackageResolver ¶
type PackageResolver struct {
// contains filtered or unexported fields
}
func NewPackageResolver ¶
func NewPackageResolver(loader *KinOpenAPI) *PackageResolver
Click to show internal directories.
Click to hide internal directories.